CONTENTS OF THIS FILE
---------------------

* Introduction
* Requirements
* Recommended modules
* Installation
* Configuration

INTRODUCTION
------------

The Search API Fusion module provides a [Lucidworks Fusion](https://lucidworks.com/products/fusion/) backend for the 
[Search API](https://www.drupal.org/project/search_api) module.
<p>All requests are routed to the <a href="https://doc.lucidworks.com/fusion/5.5/313/solr-api">Solr API</a> except:
<ul>
  <li>Search and autocomplete queries which are routed to the <a href="https://doc.lucidworks.com/fusion/5.5/361/query-api">Query API</a></li>
  <li>Signals are routed to the <a href="https://doc.lucidworks.com/fusion-server/4.2/314/signals-api">Signals API</a></li>
</ul></p>

For more information:
* Visit the project page:
  https://www.drupal.org/project/search_api_fusion

* To submit bug reports and feature suggestions, or track changes:
  https://www.drupal.org/project/issues/search_api_fusion

<h3>Features supported</h2>
<ul>
  <li>Autocompletion based on Query Pipelines (requires the module <a href="https://www.drupal.org/project/search_api_autocomplete">search_api_autocomplete</a>)</li>
  <li>Spell checking (requires the module <a href="https://www.drupal.org/project/search_api_spellcheck">search_api_spellcheck</a>)</li>
  <li>Faceting (requires the module <a href="http://drupal.org/project/facetapi">facetapi</a> in Drupal 7 and <a href="https://www.drupal.org/project/facets">facets</a> in Drupal 8+)</li>
  <li><a href="https://doc.lucidworks.com/fusion/5.5/285/landing-pages-stage">Landing pages</a> (promoted results)</li>
  <li><a href="https://doc.lucidworks.com/fusion-ai/4.0/user-guide/signals/signals.html">Request and Click Signals</a></li>
</ul>

REQUIREMENTS
------------

This module requires the following modules:
<ul>
  <li><a href="http://drupal.org/project/search_api">Search API</a></li>
  <li><a href="http://drupal.org/project/search_api_solr">Search API Solr</a> since Fusion is based on <a href="http://lucene.apache.org/solr/">Apache Solr</a></li>
  <li><a href="https://www.drupal.org/project/sarnia">Sarnia</a> (D7 only)</li>
</ul>

RECOMMENDED MODULES
-------------------
* [Search API Autocomplete](https://www.drupal.org/project/search_api_autocomplete):
  Required if you want to enable autocomplete feature.
* [Search API Spellcheck](https://www.drupal.org/project/search_api_spellcheck):
  Required if you want to enable the spell checking feature.
* Facet modules are required if you want to enable the filtering feature.
   * [Facet API](https://www.drupal.org/project/facetapi) in Drupal 7
   * [Facets](https://www.drupal.org/project/facets) in Drupal 8+


INSTALLATION
------------

* Install as you would normally install a contributed Drupal module. Visit
  https://www.drupal.org/node/1897420 for further information.
* Composer: 
    `composer require drupal/search_api_solr`

CONFIGURATION
-------------
### Drupal 7
<ol>
  <li>Enable the <strong>Search API Fusion</strong> module, its requirements and any recommended module.</li>
  <li>Go to <code>admin/config/search/search_api</code> and add a new server with service class <code>Sarnia Fusion service</code> - Sarnia should automatically generate a read-only index under this server.</li>
  <li>You can now create a view or a page based on this index, using either the <a href="https://www.drupal.org/project/search_api">Search API View</a> or <a href="https://www.drupal.org/project/search_api_page">Search API Page</a> module.</li>
  <li>To enable sending signals to Fusion go to <code>admin/config/search/search_api/server/{you_server_name}/edit</code> and check the <strong>Send signals to Fusion</strong> checkbox.</li>.
</ol>

### Drupal 9
<ol>
  <li>Enable the <strong>Search API Fusion</strong> module, its requirements and any recommended module.</li>
  <li>Go to <code>/admin/config/search/search_api</code> and add a new server with backend <code>Solr</code> and Solr connector <code>Fusion</code>. Provide a Fusion <a href="https://doc.lucidworks.com/how-to/847/create-an-app">app</a> and <a href="https://doc.lucidworks.com/fusion/5.3/174/query-profiles">search query profile.</a></li>
  <li>Create a search index based on the search server you just created ; if your Fusion index is populated via a Fusion index pipeline or some other process outside of Druapl then you may want to make it read-only.</li>
  <li>You can now create a search view at <code>/admin/structure/views</code>.</li>
  <li>Configure the user permissions in Administration » People » Permissions
    <ul>
    <li>Send signals to any Fusion server<br>
    Signals will be sent to fusion only if the user performing a search has this permission.
    </li>
  </ul>
  </li>
  <li>For autocompletion: enable <a href="https://www.drupal.org/project/search_api_autocomplete">search_api_autocomplete</a>, open the Search API Index you created and click on the <code>Autocomplete</code> tab and add a suggester <code>Fusion query profile</code>.</li>
  <li>To enable <a href="https://doc.lucidworks.com/fusion-ai/4.2/466/signals-types-and-structures#click">Click Signals</a>: </li>
  <ol>
    <li>Go to your server configuration page: <code>admin/config/search/search-api/server/{fusion_server_name}/edit</code></li>
    <li>In the CONFIGURE FUSION SOLR CONNECTOR section check the "Send click signals to Fusion" checkbox.</li>
  </ol>
  <li>To enable <a href="https://doc.lucidworks.com/fusion-ai/4.2/466/signals-types-and-structures#request">Request Signals</a> enable the Request Signal processor.</li>
  <ol>
    <li>Go to your Index processors tab: <code>admin/config/search/search-api/index/{search_api_index_name}/processors</code></li>
    <li>Check the checkbox "Send request signal to Fusion".</li>
  </ol>
</ol>
